@@ -23,7 +23,7 @@ package Data::FormValidator::Constraints;
 use strict;
 use vars qw/$AUTOLOAD @ISA @EXPORT_OK %EXPORT_TAGS $VERSION/;
 
-$VERSION = 4.50;
+$VERSION = 4.51;
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -58,9 +58,9 @@ BEGIN {
             sub $func  {
                 return sub {
                     my \$dfv = shift;
-                    use UNIVERSAL qw( can ) ;
-                    can(\$dfv, "name_this") 
-                    || die "first arg to $func was not an object. Must be called as a constraint_method.";
+		    use Scalar::Util ();
+        	    die "first arg to $func was not an object. Must be called as a constraint_method."
+		    	unless ( Scalar::Util::blessed(\$dfv) && \$dfv->can('name_this') );
 
                     \$dfv->name_this('$func');
                     no strict 'refs';
